@@ -14,6 +14,11 @@ import matplotlib.collections
 from scipy.fft import fft, fftfreq
 import NAFFlib # Numerical Analysis of the Fundamental Frequencies 
 
+# Define plotting parameters
+mpl.rcParams['axes.labelsize'] = 20
+mpl.rcParams['xtick.labelsize'] = 14
+mpl.rcParams['ytick.labelsize'] = 14
+
 # Initiate class containing helpful functions for plotting 
 class plot_tools: 
         
@@ -22,6 +27,7 @@ class plot_tools:
         Method to plot Twiss parameters
         As parameter input, can either use Xtrack, or from MAD-X generated Twiss tables 
         """
+        
         if also_closed_orbit:
             spbet = fig.add_subplot(3,1,1)
             spco = fig.add_subplot(3,1,2, sharex=spbet)
@@ -32,17 +38,17 @@ class plot_tools:
             
         spbet.plot(twiss['s'], twiss['betx'])
         spbet.plot(twiss['s'], twiss['bety'])
-        spbet.yaxis.label.set_size(18)
+        #spbet.yaxis.label.set_size(18)
 
         if also_closed_orbit:
             spco.plot(twiss['s'], twiss['x'])
             spco.plot(twiss['s'], twiss['y'])
-            spco.yaxis.label.set_size(18)
+            #spco.yaxis.label.set_size(18)
 
         spdisp.plot(twiss['s'], twiss['dx'])
         spdisp.plot(twiss['s'], twiss['dy'])
         spdisp.xaxis.label.set_size(18)
-        spdisp.yaxis.label.set_size(18)
+        #spdisp.yaxis.label.set_size(18)
 
         spbet.set_ylabel(r'$\beta_{x,y}$ [m]')
         if also_closed_orbit:
@@ -98,11 +104,7 @@ class plot_tools:
     def plot_phase_space_ellipse(fig, tracker=None, use_coords_from_tracker=True, x=None, px=None, y=None, py=None, axis='both'):
         """
         Method to plot phase space ellipse from X-suite tracking 
-        """
-        mpl.rcParams['axes.labelsize'] = 20
-        mpl.rcParams['xtick.labelsize'] = 14
-        mpl.rcParams['ytick.labelsize'] = 14
-        
+        """    
         # Use last recording from tracker, else specified x, px, y, py
         if use_coords_from_tracker:
             x = tracker.record_last_track.x
@@ -139,14 +141,9 @@ class plot_tools:
     def plot_centroid_motion(fig, tracker=None, use_coords_from_tracker=True, x=None, y=None, axis='both'):
         """
         Method to plot centroid from tracker, either in horizontal or vertical plane 
-        """
-        mpl.rcParams['axes.labelsize'] = 20
-        mpl.rcParams['xtick.labelsize'] = 14
-        mpl.rcParams['ytick.labelsize'] = 14
-        
+        """    
         fig.suptitle('X-suite tracking - centroid motion',fontsize=18)
-        
-                
+    
         # Use last recording from tracker, else specified x, px, y, py
         if use_coords_from_tracker:
             x = tracker.record_last_track.x
@@ -167,10 +164,7 @@ class plot_tools:
             plt.setp(ax.get_xticklabels(), visible=False)
         else:
             ax = fig.add_subplot(1, 1, 1)  # create an axes object in the figure
-            #ax.yaxis.label.set_size(20)
-            #ax.xaxis.label.set_size(20)
-            #plt.xticks(fontsize=14)  
-            #plt.yticks(fontsize=14)
+            
             if axis == 'horizontal':
                 ax.plot(np.mean(x, axis=0), marker='o', color='r', markersize=5)
                 ax.set_ylabel("Horizontal centroid $X$ [m]")
@@ -207,10 +201,11 @@ class plot_tools:
         fig.tight_layout()
         
         
-    def get_tune_footprint(fig, tracker):
+    def get_tune_footprint(fig, tracker, int_Q=0):
         """
         Method to find tune of all particles using NAFF (Numerical Analysis of the Fundamental Frequencies)
-        also possiblity to plot working point
+        
+        Can also add integer working tune. 
         """
         Q_x = np.zeros(len(tracker.record_last_track.x))    
         Q_y = np.zeros(len(tracker.record_last_track.y))
@@ -221,7 +216,11 @@ class plot_tools:
             
         for count, particle in enumerate(tracker.record_last_track.y):
             Q_y[count] = NAFFlib.get_tune(particle) 
-            
+
+        Q_x += int_Q
+        Q_x += int_Q
+
+        """
         fig.suptitle('Tune footprint',fontsize=18)
         ax = fig.add_subplot(1, 1, 1)  # create an axes object in the figure
         ax.yaxis.label.set_size(20)
@@ -232,10 +231,46 @@ class plot_tools:
         ax.set_ylabel("$Q_{y}$")
         ax.set_xlabel("$Q_{x}$")
         #ax.set_xlim(0.15-1e-4, 0.15+1e-4)
-
         fig.tight_layout()
+        """
         
-        return Q_x, Q_y, ax
+        return Q_x, Q_y
+    
+    
+    def plot_tune_footprint_from_tracker(fig, tracker, int_Q, Q_x=None, Q_y=None):
+        """
+        Method to plot tune footprint.
+        If Qx and Qy are not given, the method finds tune of all particles using NAFF 
+        Also returns min and max values for the tune footprints
+        """
+        # If frequency analysis has not been done before
+        if Q_x is None and Q_y is None:
+            Q_x = np.zeros(len(tracker.record_last_track.x))    
+            Q_y = np.zeros(len(tracker.record_last_track.y))
+            
+            # Iterate over turn-by-turn data to find horizontal and vertical tune of each particle
+            for count, particle in enumerate(tracker.record_last_track.x):
+                Q_x[count] = NAFFlib.get_tune(particle) 
+                
+            for count, particle in enumerate(tracker.record_last_track.y):
+                Q_y[count] = NAFFlib.get_tune(particle) 
+        else:
+            Q_x = Q_x
+            Q_y = Q_y
+        
+        # Add integer tune to fractional tune 
+        Q_x_full = Q_x+int_Q
+        Q_y_full = Q_y+int_Q
+        
+        ax = fig.add_subplot(1, 1, 1)  # create an axes object in the figure
+        ax.plot(Q_x_full, Q_y_full, 'go', markersize=3.5, alpha=0.3)
+        ax.set_ylabel("$Q_{y}$")
+        ax.set_xlabel("$Q_{x}$")
+        Qx_min, Qx_max, Qy_min, Qy_max = np.min(Q_x), np.max(Q_x), np.min(Q_y), np.max(Q_y)
+        
+        return Qx_min, Qx_max, Qy_min, Qy_max, ax    
+    
+    
     
 
 class resonance_lines(object):
@@ -244,12 +279,7 @@ class resonance_lines(object):
     Provide input of ranges in Qx and Qy, the orders and the periodiciyu of the resonances
     """    
     def __init__(self, Qx_range, Qy_range, orders, periodicity):
-        
-        # Define plotting parameters
-        mpl.rcParams['axes.labelsize'] = 20
-        mpl.rcParams['xtick.labelsize'] = 14
-        mpl.rcParams['ytick.labelsize'] = 14
-        
+           
         if np.std(Qx_range):
               self.Qx_min = np.min(Qx_range)
               self.Qx_max = np.max(Qx_range)
@@ -320,7 +350,7 @@ class resonance_lines(object):
             plt.draw()
         return ax
     
-    def plot_resonance_and_tune_footprint(self, tracker, Q_work_int = None, figure_object = None, interactive=False):    
+    def plot_resonance_and_tune_footprint(self, tracker, Q_work_int = None, figure_object = None, Q_x=None, Q_y=None, interactive=False):    
         """
         Method to plot tune footprint and resonances in the same plot 
         """
@@ -359,53 +389,33 @@ class resonance_lines(object):
                     plt.setp(line, color='r', zorder=1, linewidth=2.0) # systematic resonances
         if(interactive):
             plt.draw()
-            
-        # Get the fractional tunes from NAFF
-        Q_x = np.zeros(len(tracker.record_last_track.x))    
-        Q_y = np.zeros(len(tracker.record_last_track.y))
         
-        # Iterate over turn-by-turn data to find horizontal and vertical tune of each particle
-        for count, particle in enumerate(tracker.record_last_track.x):
-            Q_x[count] = NAFFlib.get_tune(particle) 
+        # If frequency analysis has not been done before
+        if Q_x is None and Q_y is None:
+            # Get the fractional tunes from NAFF
+            Q_x = np.zeros(len(tracker.record_last_track.x))    
+            Q_y = np.zeros(len(tracker.record_last_track.y))
             
-        for count, particle in enumerate(tracker.record_last_track.y):
-            Q_y[count] = NAFFlib.get_tune(particle) 
+            # Iterate over turn-by-turn data to find horizontal and vertical tune of each particle
+            for count, particle in enumerate(tracker.record_last_track.x):
+                Q_x[count] = NAFFlib.get_tune(particle) 
+                
+            for count, particle in enumerate(tracker.record_last_track.y):
+                Q_y[count] = NAFFlib.get_tune(particle) 
+        else:
+            Q_x = Q_x
+            Q_y = Q_y
             
         # Add integer tune to fractional tune 
         if Q_work_int is not None:
             Q_x += Q_work_int
             Q_y += Q_work_int
                         
-        ax.plot(Q_x, Q_y, 'go', markersize=6.5, alpha=0.3)
-            
-        return ax, Q_x, Q_y
-    
-        
-    def plot_tune_footprint_from_tracker(self, fig, tracker, int_Q):
-        """
-        Method to find tune of all particles using NAFF (Numerical Analysis of the Fundamental Frequencies)
-        
-        Also returns min and max values for the tune footprints
-        """
-        Q_x = np.zeros(len(tracker.record_last_track.x))    
-        Q_y = np.zeros(len(tracker.record_last_track.y))
-        
-        # Iterate over turn-by-turn data to find horizontal and vertical tune of each particle
-        for count, particle in enumerate(tracker.record_last_track.x):
-            Q_x[count] = NAFFlib.get_tune(particle) 
-            
-        for count, particle in enumerate(tracker.record_last_track.y):
-            Q_y[count] = NAFFlib.get_tune(particle) 
-        
-        # Add integer tune to fractional tune 
-        Q_x_full = Q_x+int_Q
-        Q_y_full = Q_y+int_Q
-        
-        ax = fig.add_subplot(1, 1, 1)  # create an axes object in the figure
-        ax.plot(Q_x_full, Q_y_full, 'go', markersize=3.5, alpha=0.3)
+        ax.plot(Q_x, Q_y, 'go', markersize=3.5, alpha=0.3)
         Qx_min, Qx_max, Qy_min, Qy_max = np.min(Q_x), np.max(Q_x), np.min(Q_y), np.max(Q_y)
-        
-        return Qx_min, Qx_max, Qy_min, Qy_max
+            
+        return Qx_min, Qx_max, Qy_min, Qy_max, ax       
+    
     
     def print_resonances(self):
         for resonance in self.resonance_list:
